
## Gemini
- [ ] CLI from the beginning

## Common
- [ ] [[110.description]]
- [ ] [[150.environment.setup]]
- [ ] [[180.workspace.configuration]]
- [ ] [[210.technological.stack]]
- [ ] [[220.component.architecture]]

## Specs
- [ ] [[310.spec.brainstorming]]
- [ ] [[310.spec.synthesis]] aided by AI
    - [ ]  [[ollama]]
    - [ ] [[aider]]

## Planing
- [ ] [[410.planning]]

## Develop
- [ ] [[510.develop]]
- [ ] 


## RoadMap
